/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: crsr-ptn.h,v 1.11 2010/07/30 23:01:20 bowkenken Exp $
***************************************************************/

#ifndef	CRSR_PTN_H
#define	CRSR_PTN_H

/* Υѥ󡦥ǡ */

crsr_ptn_t	crsr_ptn_dflt[] = {
	{
		-1, -1,
		0, 0,
		'@',
		{
			"@@| @@",
			"- @@- ",
			"@@| @@",
		},
	},
	{
		-1, -1,
		0, 0,
		'@',
		{
			"@\\@@/@",
			"@@@@@@",
			"@/@@\\@",
		},
	},
	{
		-1, +0,
		0, 0,
		'@',
		{
			"@@@@<=",
		},
	},
	{
		+0, +0,
		0, 0,
		'@',
		{
			"@@",
		},
	},
};

#endif	/* CRSR_PTN_H */
